==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/vi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Quản lý thông số hộp đèn Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "quản lý Thư viện ảnh");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Chiều cao");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Width ảnh");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Ảnh nhỏ Chiều cao");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bảo tồn Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Hiện trong tựa đề");
define('MANAGE_GALLERY_DISABLE_SORT', "Vô hiệu hoá theo");
define('MANAGE_GALLERY_DELETE_IMAGE', "xóa ảnh");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Lưu Xếp theo thứ tự");
define('MANAGE_GALLERY_PUBLISH_MSG', "Nhấp vào &#39;Cập nhật&#39; để xuất bản <br /> hình ảnh tải lên của bạn.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tất cả các hình ảnh đã được thay đổi kích cỡ và các thiết lập đã được lưu.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Có lỗi khi thay đổi kích thước hình ảnh hoặc lưu cài đặt.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Hình ảnh của bạn (s) đã được tải lên.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Có lỗi khi tải lên hình ảnh của bạn (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Các tập tin bạn đang cố gắng để tải lên không phải là một hình ảnh.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Các tập tin bạn đang cố gắng để tải lên quá lớn.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tiêu đề đã được lưu.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Bạn có chắc chắn muốn xóa ảnh");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Những hình ảnh đã bị xóa.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Có lỗi khi xóa hình ảnh.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Tiết kiệm thông số và thay đổi kích thước hình ảnh, xin vui lòng chờ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Tải lên, vui lòng đợi ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Thứ tự sắp xếp chưa được lưu. Bạn có muốn lưu lại thứ tự sắp xếp?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Trình tự hình ảnh loại đã được lưu.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Có lỗi khi tiết kiệm các loại hình ảnh.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/vi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Quản lý thông số hộp đèn Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "quản lý Thư viện ảnh");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Width");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Chiều cao");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Width ảnh");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Ảnh nhỏ Chiều cao");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bảo tồn Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Hiện trong tựa đề");
define('MANAGE_GALLERY_DISABLE_SORT', "Vô hiệu hoá theo");
define('MANAGE_GALLERY_DELETE_IMAGE', "xóa ảnh");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Lưu Xếp theo thứ tự");
define('MANAGE_GALLERY_PUBLISH_MSG', "Nhấp vào &#39;Cập nhật&#39; để xuất bản <br /> hình ảnh tải lên của bạn.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Tất cả các hình ảnh đã được thay đổi kích cỡ và các thiết lập đã được lưu.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Có lỗi khi thay đổi kích thước hình ảnh hoặc lưu cài đặt.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Hình ảnh của bạn (s) đã được tải lên.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Có lỗi khi tải lên hình ảnh của bạn (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Các tập tin bạn đang cố gắng để tải lên không phải là một hình ảnh.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Các tập tin bạn đang cố gắng để tải lên quá lớn.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Tiêu đề đã được lưu.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Bạn có chắc chắn muốn xóa ảnh");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Những hình ảnh đã bị xóa.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Có lỗi khi xóa hình ảnh.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Tiết kiệm thông số và thay đổi kích thước hình ảnh, xin vui lòng chờ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Tải lên, vui lòng đợi ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Thứ tự sắp xếp chưa được lưu. Bạn có muốn lưu lại thứ tự sắp xếp?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Trình tự hình ảnh loại đã được lưu.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Có lỗi khi tiết kiệm các loại hình ảnh.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Tệp bạn đang cố tải lên lớn hơn cài đặt PHP &#39;upload_max_filesize&#39; hoặc &#39;post_max_size&#39;. Liên hệ với quản trị viên hệ thống của bạn để tăng các giới hạn này.");
?>
